@@ -5,14 +5,14 @@ set -e
 
 help() {
   echo "Usage: $0 <type> <name>"
-  echo "  type: project, backend, react, svelte"
+  echo "  type: project, backend, frontend"
   echo "  name: name used everywhere in the project"
 
 }
 
 
 if [ "${1}" = "--version" ]; then
-  python${PY_VERSION} -c 'from freenit.version import version; print(version)'
+  python${PY_VERSION} -c 'from freenit import __version__; print(__version__)'
   exit 0
 fi
 
@@ -24,7 +24,7 @@ if [ -z "${TYPE}" ]; then
 fi
 
 case "${TYPE}" in
-  project|backend|react|svelte)
+  project|backend|frontend)
     ;;
   *)
     help >&2
@@ -45,17 +45,17 @@ export SED_CMD="sed -i"
 backend() {
   PROJECT_ROOT=`python${PY_VERSION} -c 'import os; import freenit; print(os.path.dirname(os.path.abspath(freenit.__file__)))'`
 
-  mkdir ${NAME}
-  cd ${NAME}
+  mkdir "${NAME}"
+  cd "${NAME}"
   cp -r ${PROJECT_ROOT}/project/* .
   case `uname` in
     *BSD)
-      ${SED_CMD} '' -e "s/NAME/${NAME}/g" setup.py
       ${SED_CMD} '' -e "s/NAME/${NAME}/g" main.py
+      ${SED_CMD} '' -e "s/NAME/${NAME}/g" pyproject.toml
       ;;
     *)
-      ${SED_CMD} -e "s/NAME/${NAME}/g" setup.py
       ${SED_CMD} -e "s/NAME/${NAME}/g" main.py
+      ${SED_CMD} -e "s/NAME/${NAME}/g" pyproject.toml
       ;;
   esac
   mv project ${NAME}
@@ -84,7 +84,6 @@ EOF
 
   cat >requirements.yml<<EOF
 - onelove-roles.freebsd-common
-- onelove-roles.freebsd_repo
 - onelove-roles.freebsd_freenit
 EOF
 
@@ -97,7 +96,6 @@ EOF
   hosts: SERVICE
   roles:
     - onelove-roles.freebsd-common
-    - onelove-roles.freebsd_repo
     - onelove-roles.freebsd_freenit
 EOF
 
@@ -150,14 +148,61 @@ dist/
 *.sqlite
 EOF
 
-  echo "Success! Please edit setup.py!"
+  echo "Success!"
   cd ..
 }
 
 
-frontend_common() {
+frontend() {
+  npx sv create "${NAME}"
+  cd "${NAME}"
+  case `uname` in
+    *BSD)
+      ${SED_CMD} '' -e "s/export default defineConfig/const config = defineConfig/" vite.config.ts
+      ${SED_CMD} '' -e 's/^\t}$/\t},/' package.json
+      ${SED_CMD} '' -e "s/^}//" package.json
+      ;;
+    *)
+      ${SED_CMD} -e "s/export default defineConfig/const config = defineConfig/" vite.config.ts
+      ${SED_CMD} -e 's/^\t}$/\t},/' package.json
+      ${SED_CMD} -e "s/^}//" package.json
+      ;;
+  esac
+  cat >>vite.config.ts<<EOF
+if (process.env.BACKEND_URL) {
+  config.server = {
+    proxy: {
+      '/api': {
+        target: process.env.BACKEND_URL,
+        changeOrigin: true,
+      }
+    }
+  }
+}
+
+export default config
+EOF
+
+  cat >>package.json<<EOF
+  "overrides": {
+    "rollup": "npm:@rollup/wasm-node"
+  }
+}
+EOF
+
+  cat >.prettierrc<<EOF
+{
+  "useTabs": false,
+  "singleQuote": true,
+  "trailingComma": "all",
+  "printWidth": 100,
+  "semi": false,
+}
+EOF
+
+  npm update --save
   echo "# ${NAME}" >README.md
-  yarn add --dev chota
+  npm install --save-dev chota
 
   mkdir bin
   cd bin
@@ -174,7 +219,7 @@ setup() {
   cd \${PROJECT_ROOT}
   update=\${1}
   if [ "\${OFFLINE}" != "yes" -a "\${update}" != "no" ]; then
-    yarn install
+    npm install
   fi
 }
 EOF
@@ -199,11 +244,11 @@ BIN_DIR=\`dirname \$0\`
 . "\${BIN_DIR}/common.sh"
 setup
 
-env CI=true yarn run test
+env CI=true npm run test
 EOF
   chmod +x test.sh
 
-  cat >collect.sh<<EOF
+  cat >build.sh<<EOF
 #!/bin/sh
 
 
@@ -216,9 +261,10 @@ echo "Frontend"
 echo "========"
 cd "\${PROJECT_ROOT}"
 rm -rf build
-yarn run build
+npm run build
+touch build/.keep
 EOF
-  chmod +x collect.sh
+  chmod +x build.sh
 
   cd ..
 
@@ -244,8 +290,8 @@ EOF
 
   cat >requirements.yml<<EOF
 - onelove-roles.freebsd-common
-- onelove-roles.freebsd_repo
 - onelove-roles.freebsd_node
+- onelove-roles.freebsd_pm2
 EOF
 
   cat >templates/site.yml.tpl<<EOF
@@ -257,23 +303,37 @@ EOF
   hosts: SERVICE
   roles:
     - onelove-roles.freebsd-common
-    - onelove-roles.freebsd_repo
     - onelove-roles.freebsd_node
+    - onelove-roles.freebsd_pm2
 EOF
 
   cat >.gitignore<<EOF
-.DS_Store
 node_modules
-build
-.svelte-kit
-package
+
+# Output
+.output
+.vercel
+.netlify
+.wrangler
+/.svelte-kit
+/build
+/dist
+
+# OS
+.DS_Store
+Thumbs.db
+
+# Env
 .env
 .env.*
-.vercel
-.output
-dist
-stats.html
+!.env.example
+!.env.test
 
+# Vite
+vite.config.js.timestamp-*
+vite.config.ts.timestamp-*
+
+# Reggae
 .provisioned
 ansible/group_vars/all
 ansible/inventory/inventory
@@ -287,99 +347,254 @@ site.retry
 project.mk
 vars.mk
 EOF
+
+  npm install --save-dev @zerodevx/svelte-toast @freenit-framework/core @sveltejs/adapter-node @mdi/js
+
+  rm -rf src/lib
+  rm -rf src/routes/about src/routes/sverdle src/routes/*.svelte src/app.css
+
+  cat >src/routes/styles.css<<EOF
+:root {
+  font-family: Arial, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto,
+    Oxygen, Ubuntu, Cantarell, 'Open Sans', 'Helvetica Neue', sans-serif;
 }
 
-react() {
-  yarn init vite@latest "${NAME}" -- --template react-ts
-  cd "${NAME}"
-  yarn install @freenit-framework/axios react-router-dom @mdi/js
-  frontend_common
+body {
+  min-height: 100vh;
+  margin: 0;
+  padding: 0;
+}
 
-  rm src/App.* src/index.css src/logo.svg
-  mkdir src/routes
-  cat >src/routing.tsx<<EOF
-import React, { Fragment } from 'react'
-import { Route, Routes } from 'react-router-dom'
-
-const PRESERVED = import.meta.globEager('/src/routes/(_app|404).tsx')
-const ROUTES = import.meta.globEager('/src/routes/**/[a-z[]*.tsx')
-
-const preserved: { [key: string]: any } = Object.keys(PRESERVED).reduce((preserved, file) => {
-  const key = file.replace(/\/src\/routes\/|\.tsx$/g, '')
-  return { ...preserved, [key]: PRESERVED[file].default }
-}, {})
-
-const routes = Object.keys(ROUTES).map((route) => {
-  const path = route
-    .replace(/\/src\/routes|index|\.tsx$/g, '')
-    .replace(/\[\.{3}.+\]/, '*')
-    .replace(/\[(.+)\]/, ':')
-
-  return { path, component: ROUTES[route].default }
-})
-
-export const Routing = () => {
-  const NotFound = preserved?.['404'] || Fragment
-
-  return (
-    <Routes>
-      {routes.map(({ path, component: Component = Fragment }) => (
-        <Route key={path} path={path} element={<Component />} />
-      ))}
-      <Route path="*" element={<NotFound />} />
-    </Routes>
-  )
+:root {
+  --bg-color: #ffffff;
+  --bg-secondary-color: #f3f3f6;
+  --color-primary: #14854F;
+  --color-lightGrey: #d2d6dd;
+  --color-grey: #747681;
+  --color-darkGrey: #3f4144;
+  --color-error: #d43939;
+  --color-success: #28bd14;
+  --grid-maxWidth: 120rem;
+  --grid-gutter: 2rem;
+  --font-size: 1.6rem;
+  --font-color: #333333;
+  --font-family-sans: sans-serif;
+  --font-family-mono: monaco, "Consolas", "Lucida Console", monospace;
 }
 EOF
 
-  cat >src/main.tsx<<EOF
-import React, { StrictMode } from 'react'
-import { createRoot } from 'react-dom/client'
-import { BrowserRouter } from 'react-router-dom'
-import 'chota'
-import { Routing } from './routing'
+  cat >src/routes/+layout.svelte<<EOF
+<script lang="ts">
+  import './styles.css'
+  import 'chota'
+  import { onMount } from 'svelte'
+  import { SvelteToast } from '@zerodevx/svelte-toast'
+  import { LeftPane, MenuItems, MenuBar } from '@freenit-framework/core'
+  import store from '\$lib/store'
 
-const container = document.getElementById('root');
-const root = createRoot(container!);
-root.render(
-  <StrictMode>
-    <BrowserRouter>
-      <Routing />
-    </BrowserRouter>
-  </StrictMode>
-);
-EOF
+  const options = {}
+  let { children } = \$props()
+  let open = \$state(false)
 
-  cat >src/routes/index.tsx<<EOF
-export default function Landing() {
-  return (
-    <div>Hello World!</div>
-  )
-}
-EOF
-
-  case `uname` in
-    *BSD)
-      ${SED_CMD} '' -e "s/})//g" vite.config.ts
-      ${SED_CMD} '' -e "s/plugins: \(.*\)/plugins: \1,/g" vite.config.ts
-      ;;
-    *)
-      ${SED_CMD} -e "s/})//g" vite.config.ts
-      ${SED_CMD} -e "s/plugins: \(.*\)/plugins: \1,/g" vite.config.ts
-      ;;
-  esac
-  cat >>vite.config.ts<<EOF
-  server: {
-    proxy: {
-      '/api': {
-        target: process.env.BACKEND_URL,
-        changeOrigin: true
-      }
-    }
+  const toggle = () => {
+    open = !open
   }
-})
+
+  const logout = async () => {
+    open = !open
+    await store.auth.logout()
+  }
+
+  onMount(async () => { await store.auth.refresh_token() })
+</script>
+
+<svelte:head>
+  <title>${NAME}</title>
+  <meta name="${NAME}" content="${NAME}" />
+</svelte:head>
+
+<SvelteToast {options} />
+<LeftPane {open} {toggle}>
+  <MenuItems {toggle} {logout} {store} />
+</LeftPane>
+
+<section class="root">
+  <MenuBar {toggle} title="${NAME}" />
+  <div class="main">
+    {@render children?.()}
+  </div>
+</section>
+
+<style>
+  .root {
+    height: 100dvh;
+    display: flex;
+    flex-direction: column;
+  }
+
+  .main {
+    height: 100%;
+    width: 100%;
+  }
+</style>
 EOF
 
+  cat >src/routes/+page.svelte <<EOF
+<div class="root">
+  <div>Landing page is in src/routes/+page.svelte</div>
+  <div>Menu and layout are in src/routes/+layout.svelte</div>
+</div>
+EOF
+
+  mkdir src/routes/login
+  cat >src/routes/login/+page.svelte <<EOF
+<script lang="ts">
+  import { Login } from '@freenit-framework/core'
+  import store from '\$lib/store'
+</script>
+
+<Login store={store} />
+EOF
+
+  mkdir src/routes/register
+  cat >src/routes/register/+page.svelte <<EOF
+<script lang="ts">
+  import { Register } from '@freenit-framework/core'
+  import store from '\$lib/store'
+</script>
+
+<Register store={store} />
+EOF
+
+  mkdir -p 'src/routes/verify/[token]'
+  cat >'src/routes/verify/[token]/+page.ts' <<EOF
+export const load = ({ params }) => {
+  return {
+    token: params.token
+  }
+}
+EOF
+  cat >'src/routes/verify/[token]/+page.svelte' <<EOF
+<script lang="ts">
+  import { onMount } from 'svelte'
+  import { goto } from '\$app/navigation'
+  import store from '\$lib/store'
+
+  const { data: props } = \$props()
+
+  onMount(async () => {
+    const response = await store.auth.verify(props.token)
+    if (response.ok) {
+      goto('/login')
+    }
+  })
+</script>
+EOF
+  cat >'src/routes/verify/+page.svelte' <<EOF
+<div class="root">
+  <h1>Welcome</h1>
+  <p>You should receive email to verify your account shortly!</p>
+</div>
+
+<style>
+  .root {
+    display: flex;
+    align-items: center;
+    justify-content: center;
+    flex-direction: column;
+    height: 100%;
+  }
+</style>
+EOF
+
+  mkdir -p 'src/routes/users/[pk]'
+  cat >'src/routes/users/[pk]/+page.ts' <<EOF
+export const load = ({ params }) => {
+  return {
+    pk: params.pk
+  }
+}
+EOF
+  cat >'src/routes/users/[pk]/+page.svelte' <<EOF
+<script lang="ts">
+  import { User } from '@freenit-framework/core'
+  import store from '\$lib/store'
+
+  const { data: props } = \$props()
+</script>
+
+<User pk={props.pk} store={store} />
+EOF
+  cat >'src/routes/users/+page.svelte' <<EOF
+<script lang="ts">
+  import { Users } from '@freenit-framework/core'
+  import store from '\$lib/store'
+</script>
+
+<Users store={store} />
+EOF
+
+  mkdir -p 'src/routes/roles/[pk]'
+  cat >'src/routes/roles/[pk]/+page.ts' <<EOF
+export const load = ({ params }) => {
+  return {
+    pk: params.pk
+  }
+}
+EOF
+  cat >'src/routes/roles/[pk]/+page.svelte' <<EOF
+<script lang="ts">
+  import { Role } from '@freenit-framework/core'
+  import store from '\$lib/store'
+
+  const { data: props } = \$props()
+</script>
+
+<Role pk={props.pk} store={store} />
+EOF
+  cat >'src/routes/roles/+page.svelte' <<EOF
+<script lang="ts">
+  import { Roles } from '@freenit-framework/core'
+  import store from '\$lib/store'
+</script>
+
+<Roles store={store} />
+EOF
+
+  mkdir -p 'src/routes/profile/password'
+  cat >'src/routes/profile/+page.svelte' <<EOF
+<script lang="ts">
+  import { Profile } from '@freenit-framework/core'
+  import store from '\$lib/store'
+</script>
+
+<Profile store={store} />
+
+EOF
+  cat >'src/routes/profile/password/+page.svelte' <<EOF
+<script lang="ts">
+  import { Password } from '@freenit-framework/core'
+  import store from '\$lib/store'
+</script>
+
+<Password store={store} />
+EOF
+
+  mkdir -p src/lib/store
+  cat >'src/lib/store/index.ts' <<EOF
+import { BaseStore } from '@freenit-framework/core'
+
+class Store extends BaseStore {
+  constructor(prefix='/api/v1') {
+    super(prefix)
+  }
+}
+
+const store = new Store()
+export default store
+EOF
+
+  npm run format
   cd bin
   cat >devel.sh<<EOF
 #!/bin/sh
@@ -391,64 +606,13 @@ setup
 
 echo "Frontend"
 echo "========"
-env BACKEND_URL=\${BACKEND_URL} yarn run dev -- --host 0.0.0.0
-EOF
-  chmod +x devel.sh
-  cd ..
-}
-
-svelte() {
-  yarn create svelte "${NAME}"
-  cd "${NAME}"
-  yarn install
-  frontend_common
-  cat >.prettierrc<<EOF
-{
-  "useTabs": false,
-  "singleQuote": true,
-  "trailingComma": "all",
-  "printWidth": 80,
-  "semi": false,
-}
-EOF
-
-  case `uname` in
-    *BSD)
-      ${SED_CMD} '' -e "s/export default config//g" vite.config.ts
-      ;;
-    *)
-      ${SED_CMD} -e "s/export default config//g" vite.config.ts
-      ;;
-  esac
-  cat >>vite.config.ts<<EOF
-if (process.env.BACKEND_URL) {
-  config.server = {
-    proxy: {
-      '/api': process.env.BACKEND_URL
-    }
-  }
-}
-
-export default config
-EOF
-  yarn run format
-  cd bin
-  cat >devel.sh<<EOF
-#!/bin/sh
-
-
-BIN_DIR=\`dirname \$0\`
-. "\${BIN_DIR}/common.sh"
-setup
-
-echo "Frontend"
-echo "========"
-env BACKEND_URL=\${BACKEND_URL} yarn run dev -- --host 0.0.0.0
+env BACKEND_URL=\${BACKEND_URL} npm run dev -- --host 0.0.0.0
 EOF
   chmod +x devel.sh
   cd ../..
 }
 
+
 project() {
   echo "Creating project"
   mkdir "${NAME}"
@@ -501,9 +665,9 @@ for service in \${SERVICES}; do
     fi
   else
     if [ "\${REGGAE}" = "yes" ]; then
-      sudo tmux split-window -h -p 50 -t 0 "make -C services/\${service} BACKEND_URL=http://\${backend_hostname}:5000 devel offline=\${OFFLINE}"
+      sudo tmux split-window -t 0 "make -C services/\${service} BACKEND_URL=http://\${backend_hostname}:5000 devel offline=\${OFFLINE}"
     else
-      tmux split-window -h -p 50 -t 0 "env OFFLINE=\${OFFLINE} BACKEND_URL=http://\${backend_hostname}:5000 \${PROJECT_ROOT}/services/\${service}/bin/devel.sh"
+      tmux split-window -t 0 "env OFFLINE=\${OFFLINE} BACKEND_URL=http://\${backend_hostname}:5000 \${PROJECT_ROOT}/services/\${service}/bin/devel.sh"
     fi
   fi
 done
@@ -573,8 +737,6 @@ services/
 vars.mk
 EOF
 
-  echo "DEVEL_MODE = YES" >vars.mk
-
   echo "Creating services"
   mkdir services
   cd services
@@ -584,15 +746,7 @@ EOF
   mv "${NAME}" backend
 
   echo "Creating frontend"
-  FRONTEND_TYPE=${FRONTEND_TYPE:=svelte}
-  if [ "${FRONTEND_TYPE}" = "svelte" ]; then
-    svelte
-  elif [ "${FRONTEND_TYPE}" = "react" ]; then
-    react
-  else
-    help >&2
-    exit 1
-  fi
+  frontend
   mv "${NAME}" frontend
   cd ..
 }
