@@ -1,23 +1,21 @@
+from contextlib import asynccontextmanager
 from fastapi import FastAPI
 
-import freenit.config
+from .config import getConfig
 
 from .api import api
 
-config = freenit.config.getConfig()
-app = FastAPI()
+config = getConfig()
 
 
-@app.on_event("startup")
-async def startup() -> None:
+@asynccontextmanager
+async def lifespan(_: FastAPI):
     if not config.database.is_connected:
         await config.database.connect()
-
-
-@app.on_event("shutdown")
-async def shutdown() -> None:
+    yield
     if config.database.is_connected:
         await config.database.disconnect()
 
 
+app = FastAPI(lifespan=lifespan)
 app.mount(config.api_root, api)
