@@ -2,5 +2,11 @@ from freenit.config import getConfig
 
 config = getConfig()
 auth = config.get_model("role")
-Role = auth.Role
-RoleOptional = auth.RoleOptional
+
+
+class Role(auth.Role):
+    pass
+
+
+class RoleOptional(auth.RoleOptional):
+    pass
