@@ -2,5 +2,11 @@ from freenit.config import getConfig
 
 config = getConfig()
 auth = config.get_model("user")
-User = auth.User
-UserOptional = auth.UserOptional.get_pydantic(exclude={"admin", "active"})
+
+
+class User(auth.User):
+    pass
+
+
+class UserOptional(auth.UserOptional):
+    pass
