@@ -1,6 +1,8 @@
 from freenit.auth import permissions
 
-role_perms = permissions()
+domain_perms = permissions()
+group_perms = permissions()
 profile_perms = permissions()
-user_perms = permissions()
+role_perms = permissions()
 theme_perms = permissions()
+user_perms = permissions()
