@@ -1,14 +1,12 @@
 import pytest
 
-from freenit.models.user import User
-
 from . import factories
 
 
 @pytest.mark.asyncio
 class TestAuth:
     async def test_login(self, client):
-        user: User = factories.User()
+        user = factories.User()
         await user.save()
         response = client.login(user=user)
 
@@ -23,7 +21,7 @@ class TestAuth:
         assert response.status_code == 200
 
     async def test_refresh(self, client):
-        user: User = factories.User()
+        user = factories.User()
         await user.save()
         client.login(user=user)
         response = client.post("/auth/refresh")
